@@ -5,7 +5,7 @@ use Carp;
 require 5.000;
 
 @ISA = qw(Exporter);
-@EXPORT = qw(days_in is_leapyear);
+@EXPORT = qw(days_in is_leap);
 @EXPORT_OK = qw(%mltable);
 
 use strict;
@@ -56,7 +56,7 @@ __DATA__
 Time::DaysInMonth -- simply report the number of days in a month
 
 =head1 SYNOPSIS
-	
+
 	use Time::DaysInMonth;
 	$days = days_in($year, $month_1_to_12);
 	$leapyear = is_leap($year);
